@@ -5,7 +5,6 @@ from scipy.stats import beta as beta_dist, rv_continuous
 from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
     BetaFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.domains import FixedDomainMixin
 from probability.distributions.mixins.rv_continuous_1d_mixin import \
     RVContinuous1dMixin
 from probability.distributions.mixins.rv_mixins import NUM_SAMPLES_COMPARISON
@@ -18,7 +17,6 @@ class Beta(
     AlphaFloatDMixin,
     BetaFloatDMixin,
     CalculableMixin,
-    FixedDomainMixin,
     object
 ):
     """
@@ -99,3 +97,7 @@ class Beta(
             abs(self._alpha - other._alpha) < 1e-10 and
             abs(self._beta - other._beta) < 1e-10
         )
+
+    def __ne__(self, other: 'Beta') -> bool:
+
+        return not self.__eq__(other)
