@@ -40,6 +40,14 @@ class ContinuousUniform(
         self._a = a
         self._b = b
 
+    @property
+    def lower_bound(self) -> float:
+        return self._a
+
+    @property
+    def upper_bound(self) -> float:
+        return self._b
+
     def _reset_distribution(self):
 
         self._distribution = uniform(loc=self._a, scale=self._b - self._a)
@@ -62,3 +70,7 @@ class ContinuousUniform(
             abs(self._a - other._a) < 1e-10 and
             abs(self._b - other._b) < 1e-10
         )
+
+    def __ne__(self, other: 'ContinuousUniform') -> bool:
+
+        return not self.__eq__(other)
