@@ -36,6 +36,14 @@ class Exponential(
 
         self._distribution: rv_continuous = expon(loc=0, scale=1 / self._lambda)
 
+    @property
+    def lower_bound(self) -> float:
+        return 0.0
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     def mode(self) -> float:
         return 0.0
 
@@ -50,3 +58,7 @@ class Exponential(
     def __eq__(self, other: 'Exponential') -> bool:
 
         return abs(self._lambda - other._lambda) < 1e-10
+
+    def __ne__(self, other: 'Exponential') -> bool:
+
+        return not self.__eq__(other)
