@@ -83,6 +83,14 @@ class Gamma(
         else:
             raise ValueError("Can't calculate mode for this distribution.")
 
+    @property
+    def lower_bound(self) -> float:
+        return 0.0
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     def __str__(self):
 
         if self._parameterization == 'αβ':
@@ -111,3 +119,7 @@ class Gamma(
             abs(self._alpha - other._alpha) < 1e-10 and
             abs(self._beta - other._beta) < 1e-10
         )
+
+    def __ne__(self, other: 'Gamma') -> bool:
+
+        return not self.__eq__(other)
