@@ -47,6 +47,14 @@ class InvGamma(
 
         return self.beta / (self.alpha + 1)
 
+    @property
+    def lower_bound(self) -> float:
+        return 0.0
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     def __str__(self):
 
         return (
@@ -65,3 +73,7 @@ class InvGamma(
             abs(self._alpha - other._alpha) < 1e-10 and
             abs(self._beta - other._beta) < 1e-10
         )
+
+    def __ne__(self, other: 'InvGamma') -> bool:
+
+        return not self.__eq__(other)
