@@ -43,6 +43,14 @@ class Laplace(
 
         return self._mu
 
+    @property
+    def lower_bound(self) -> float:
+        return self.isf().at(0.99)
+
+    @property
+    def upper_bound(self) -> float:
+        return self.isf().at(0.01)
+
     def __str__(self):
         return (
             f'Laplace('
@@ -59,3 +67,7 @@ class Laplace(
             abs(self._mu - other._mu) < 1e-10 and
             abs(self._b - other._b) < 1e-10
         )
+
+    def __ne__(self, other: 'Laplace') -> bool:
+
+        return not self.__eq__(other)
