@@ -35,6 +35,14 @@ class Geometric(
 
         self._distribution: rv_discrete = geom(self._p)
 
+    @property
+    def lower_bound(self) -> int:
+        return 1
+
+    @property
+    def upper_bound(self) -> int:
+        return int(self.isf().at(0.01))
+
     def mode(self) -> int:
 
         return 1
@@ -53,3 +61,12 @@ class Geometric(
             return self.pmf().at(other)
         else:
             return abs(self._p - other._p) < 1e-10
+
+    def __ne__(
+            self, other: Union['Geometric', int, float]
+    ) -> Union[bool, float]:
+
+        if type(other) in (int, float):
+            return 1 - self.pmf().at(other)
+        else:
+            return not self.__eq__(other)
