@@ -47,6 +47,14 @@ class NegativeBinomial(
         """
         self._distribution: rv_discrete = nbinom(self._r, 1 - self._p)
 
+    @property
+    def lower_bound(self) -> int:
+        return 1
+
+    @property
+    def upper_bound(self) -> int:
+        return int(self.isf().at(0.01))
+
     @property
     def r(self) -> float:
         return self._r
@@ -84,3 +92,12 @@ class NegativeBinomial(
                 self._r == other._r and
                 abs(self._p - other._p) < 1e-10
             )
+
+    def __ne__(
+            self, other: Union['NegativeBinomial', int, float]
+    ) -> Union[bool, float]:
+
+        if type(other) in (int, float):
+            return 1 - self.pmf().at(other)
+        else:
+            return not self.__eq__(other)
